<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // exit if access directly.
}

if ( ( class_exists( 'LearnDash_Settings_Section' ) ) && ( ! class_exists( 'LearnDash_Settings_FBT_Fields' ) ) ) {
	/**
	 * Class LearnDash Settings Section for Custom Labels Metabox.
	 */
	class LearnDash_Settings_FBT_Fields extends LearnDash_Settings_Section {

		/**
		 * Protected constructor for class
		 */
		protected function __construct() {

			// setting page id.
			$this->settings_page_id = 'ldfbt_upsell_settings';

			// This is the 'option_name' key used in the wp_options table.
			$this->setting_option_key = 'ldfbt_upsells';

			// This is the HTML form field prefix used.
			$this->setting_field_prefix = 'ldfbt_upsells';

			// Used within the Settings API to uniquely identify this section.
			$this->settings_section_key = 'ldfbt_upsells_fields';

			// Section label/header.
			$this->settings_section_label = esc_html__( 'Frequently Bought Together', 'ldfbt-frequently-bought-products' );

			// Section discription.
			$this->settings_section_description = esc_html__( 'Frequently Bought Together for LearnDash Settings', 'ldfbt-frequently-bought-products' );

			parent::__construct();
		}

		/**
		 * Initialize the metabox settings values.
		 */
		public function load_settings_values() {
			parent::load_settings_values();

			if ( false === $this->setting_option_values ) {
				$this->setting_option_values = get_option( 'learndash_custom_label_settings' );
			}

			if ( ( isset( $_GET['action'] ) ) && ( 'ld_reset_settings' === $_GET['action'] ) && ( isset( $_GET['page'] ) ) && ( $_GET['page'] === $this->settings_page_id ) ) {
				if ( ( isset( $_GET['ld_wpnonce'] ) ) && ( ! empty( $_GET['ld_wpnonce'] ) ) ) {
					if ( wp_verify_nonce( $_GET['ld_wpnonce'], get_current_user_id() . '-' . $this->setting_option_key ) ) {
						if ( ! empty( $this->setting_option_values ) ) {
							foreach ( $this->setting_option_values as $key => $val ) {
								$this->setting_option_values[ $key ] = '';
							}
							$this->save_settings_values();
						}
						$reload_url = remove_query_arg( array( 'action', 'ld_wpnonce' ) );
						learndash_safe_redirect( $reload_url );
					}
				}
			}
		}

		/**
		 * Initialize the metabox settings fields.
		 */
		public function load_settings_fields() {
			$this->setting_option_fields = array(

				// plugin type option.
				'ldfbt_plugin_type'     => array(
					'name'      => 'ldfbt_plugin_type',
					'label'     => esc_html__( 'Choose Frequently Bought Together (FBT) Configuration', 'ldfbt-frequently-bought-products' ),
					'help_text' => esc_html__( 'Please choose the plugin with which you intend to sell courses on this site.', 'ldfbt-frequently-bought-products' ),
					'type'      => 'radio',
					'value'     => $this->setting_option_values['ldfbt_plugin_type'] ? $this->setting_option_values['ldfbt_plugin_type'] : ldfbt_make_default_option(),
					'options'   => array(
						'woocom' => array(
							'label' => esc_html__( 'WooCommerce', 'ldfbt-frequently-bought-products' ),
						),
						'edd'    => array(
							'label' => esc_html__( 'Easy Digital Downloads (EDD)', 'ldfbt-frequently-bought-products' ),
						),
					),
				),

				// WC enroller count option.
				'ldfbt_enroller_enable' => array(
					'name'      => 'ldfbt_enroller_enable',
					'type'      => 'checkbox-switch',
					'label'     => esc_html__( 'Display enroll count for the course', 'ldfbt-frequently-bought-products' ),
					'help_text' => esc_html__( 'Shows a count of users (who enrolled for that course) next to each course in the FBT widget.', 'ldfbt-frequently-bought-products' ),
					'value'     => isset( $this->setting_option_values['ldfbt_enroller_enable'] ) ? $this->setting_option_values['ldfbt_enroller_enable'] : '',
					'options'   => array(
						'yes' => '',
					),
				),

				// widget heading inpiut field.
				'ldfbt_widget_heading'  => array(
					'name'      => 'ldfbt_widget_heading',
					'type'      => 'text',
					'default'   => 'small',
					'label'     => esc_html__( 'FBT Widget Title', 'ldfbt-frequently-bought-products' ),
					'help_text' => esc_html__( 'Use this setting to give a suitable heading to your Frequently Bough Together widget', 'ldfbt-frequently-bought-products' ),
					'value'     => '' !== $this->setting_option_values['ldfbt_widget_heading'] ? $this->setting_option_values['ldfbt_widget_heading'] : 'Frequently Bought Together',
					'class'     => 'regular-text',
				),
			);

			/**
			 * Filters custom lables setting fields.
			 *
			 * @param array $setting_option_fields Associative array of Setting field details like name,type,label,value.
			 */
			$this->setting_option_fields = apply_filters( 'learndash_custom_label_fields', $this->setting_option_fields );
			$this->setting_option_fields = apply_filters( 'learndash_settings_fields', $this->setting_option_fields, $this->settings_section_key );
			parent::load_settings_fields();
		}

		/**
		 * Save settings
		 *
		 * @param array  $new_values         Array of section fields values.
		 * @param array  $old_values         Array of old values.
		 * @param string $setting_option_key Section option key should match $this->setting_option_key.
		 */
		public function section_pre_update_option( $new_values = '', $old_values = '', $setting_option_key = '' ) {
			if ( $setting_option_key === $this->setting_option_key ) {
				$new_values = parent::section_pre_update_option( $new_values, $old_values, $setting_option_key );

				// cheks the index of all the fields and update the default value.
				if ( $new_values !== $old_values ) {

					// sets the plugin type default.
					if ( ! isset( $new_values['ldfbt_plugin_type'] ) ) {
						$new_values['ldfbt_plugin_type'] = 'woocom';
					}

					// sets the default option for enroller count.
					if ( ! isset( $new_values['ldfbt_enroller_enable'] ) ) {
						$new_values['ldfbt_enroller_enable'] = '';
					}

					// set the default course limit.
					if ( ! isset( $new_values['ldfbt_widget_img_size'] ) ) {
						$new_values['ldfbt_widget_img_size'] = 'small';
					}

					// set the default upsell heading.
					if ( ! isset( $new_values['ldfbt_widget_heading'] ) ) {
						$new_values['ldfbt_widget_heading'] = 'Students also bought';
					}
				}
			}
			return $new_values;
		}
	}
}
add_action(
	'learndash_settings_sections_init',
	function () {
		LearnDash_Settings_FBT_Fields::add_section_instance();
	}
);
